@@ -5,7 +5,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 $VERSION = eval $VERSION;
 
 require XSLoader;
@@ -17,16 +17,19 @@ our @EXPORT_OK = ( qw/
 / );
 
 sub int_multi {
-  my $opts;
-  if (eval { ref $_[-1] eq 'HASH' }) {
-    $opts = pop;
+  croak "int_multi requires 3 arguments, aside from an options hash(ref)" 
+    unless @_ >= 3;
+
+  my ($sub, $xl, $xu) = (shift, shift, shift);
+ 
+  my %opts;
+  if (@_) {
+    %opts = ref $_[0] ? %{shift()} : @_;
   }
-  $opts->{calls} ||= 500000;
 
-  croak "int_multi requires 3 arguments, aside from an options hashref" 
-    unless @_ == 3;
+  $opts{calls} ||= 500000;
 
-  my $ret = c_int_multi(@_, $opts->{calls});
+  my $ret = c_int_multi($sub, $xl, $xu, $opts{calls});
   return wantarray ? @$ret : $ret->[0];
 }
 
@@ -73,7 +76,7 @@ In scalar context the result is returned, in list context the result and the sta
 
 =back
 
-=head1 INSTALLTION REQUIREMENTS
+=head1 INSTALLATION REQUIREMENTS
 
 This module needs the GSL library installed and available. The C<PERLGSL_LIBS> environment variable may be used to pass the C<--libs> linker flags; if this is not specified, the command C<gsl-config --libs> is executed to find them. Future plans include using an L<Alien> module to provide the GSL in a more CPAN-friendly manner.
 
